.. _all-salt.states:

=============
state modules
=============

.. currentmodule:: salt.states

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    acme
    alias
    alternatives
    ansiblegate
    apache
    apache_conf
    apache_module
    apache_site
    aptpkg
    archive
    artifactory
    at
    augeas
    aws_sqs
    beacon
    bigip
    blockdev
    boto3_elasticache
    boto3_elasticsearch
    boto3_route53
    boto3_sns
    boto_apigateway
    boto_asg
    boto_cfn
    boto_cloudfront
    boto_cloudtrail
    boto_cloudwatch_alarm
    boto_cloudwatch_event
    boto_cognitoidentity
    boto_datapipeline
    boto_dynamodb
    boto_ec2
    boto_elasticache
    boto_elasticsearch_domain
    boto_elb
    boto_elbv2
    boto_iam
    boto_iam_role
    boto_iot
    boto_kinesis
    boto_kms
    boto_lambda
    boto_lc
    boto_rds
    boto_route53
    boto_s3
    boto_s3_bucket
    boto_secgroup
    boto_sns
    boto_sqs
    boto_vpc
    bower
    btrfs
    cabal
    ceph
    chef
    chocolatey
    chronos_job
    cimc
    cisconso
    cloud
    cmd
    composer
    consul
    cron
    cryptdev
    csf
    cyg
    ddns
    debconfmod
    dellchassis
    disk
    docker_container
    docker_image
    docker_network
    docker_volume
    drac
    dvs
    elasticsearch
    elasticsearch_index
    elasticsearch_index_template
    environ
    eselect
    esxcluster
    esxdatacenter
    esxi
    esxvm
    etcd_mod
    ethtool
    event
    file
    firewall
    firewalld
    gem
    git
    github
    glance_image
    glassfish
    glusterfs
    gnomedesktop
    gpg
    grafana
    grafana4_dashboard
    grafana4_datasource
    grafana4_org
    grafana4_user
    grafana_dashboard
    grafana_datasource
    grains
    group
    heat
    helm
    hg
    highstate_doc
    host
    http
    icinga2
    idem
    ifttt
    incron
    influxdb08_database
    influxdb08_user
    influxdb_continuous_query
    influxdb_database
    influxdb_retention_policy
    influxdb_user
    infoblox_a
    infoblox_cname
    infoblox_host_record
    infoblox_range
    ini_manage
    ipmi
    ipset
    iptables
    jboss7
    jenkins
    junos
    kapacitor
    kernelpkg
    keyboard
    keystone
    keystone_domain
    keystone_endpoint
    keystone_group
    keystone_project
    keystone_role
    keystone_role_grant
    keystone_service
    keystone_user
    keystore
    kmod
    kubernetes
    layman
    ldap
    libcloud_dns
    libcloud_loadbalancer
    libcloud_storage
    linux_acl
    locale
    logadm
    logrotate
    loop
    lvm
    lvs_server
    lvs_service
    lxc
    lxd
    lxd_container
    lxd_image
    lxd_profile
    mac_assistive
    mac_keychain
    mac_xattr
    macdefaults
    macpackage
    makeconf
    marathon_app
    mdadm_raid
    memcached
    modjk
    modjk_worker
    module
    mongodb_database
    mongodb_user
    monit
    mount
    mssql_database
    mssql_login
    mssql_role
    mssql_user
    msteams
    mysql_database
    mysql_grants
    mysql_query
    mysql_user
    net_napalm_yang
    netacl
    netconfig
    netntp
    netsnmp
    netusers
    network
    neutron_network
    neutron_secgroup
    neutron_secgroup_rule
    neutron_subnet
    nexus
    nfs_export
    nftables
    npm
    ntp
    nxos
    nxos_upgrade
    openstack_config
    openvswitch_bridge
    openvswitch_db
    openvswitch_port
    opsgenie
    pagerduty
    pagerduty_escalation_policy
    pagerduty_schedule
    pagerduty_service
    pagerduty_user
    panos
    pbm
    pcs
    pdbedit
    pecl
    pip_state
    pkg
    pkgbuild
    pkgng
    pkgrepo
    portage_config
    ports
    postgres_cluster
    postgres_database
    postgres_extension
    postgres_group
    postgres_initdb
    postgres_language
    postgres_privileges
    postgres_schema
    postgres_tablespace
    postgres_user
    powerpath
    probes
    process
    proxy
    pushover
    pyenv
    pyrax_queues
    quota
    rabbitmq_cluster
    rabbitmq_plugin
    rabbitmq_policy
    rabbitmq_upstream
    rabbitmq_user
    rabbitmq_vhost
    rbac_solaris
    rbenv
    rdp
    redismod
    reg
    restconf
    rsync
    rvm
    salt_proxy
    saltmod
    saltutil
    schedule
    selinux
    serverdensity_device
    service
    slack
    smartos
    smtp
    snapper
    solrcloud
    splunk
    splunk_search
    sqlite3
    ssh_auth
    ssh_known_hosts
    stateconf
    status
    statuspage
    supervisord
    svn
    sysctl
    sysfs
    syslog_ng
    sysrc
    telemetry_alert
    test
    testinframod
    timezone
    tls
    tomcat
    trafficserver
    tuned
    uptime
    user
    vagrant
    vault
    vbox_guest
    victorops
    virt
    virtualenv_mod
    webutil
    win_appx
    win_certutil
    win_dacl
    win_dism
    win_dns_client
    win_firewall
    win_iis
    win_lgpo
    win_lgpo_reg
    win_license
    win_network
    win_path
    win_pki
    win_powercfg
    win_servermanager
    win_shortcut
    win_smtp_server
    win_snmp
    win_system
    win_task
    win_wua
    win_wusa
    winrepo
    wordpress
    x509
    x509_v2
    xml
    xmpp
    zabbix_action
    zabbix_host
    zabbix_hostgroup
    zabbix_mediatype
    zabbix_template
    zabbix_user
    zabbix_usergroup
    zabbix_usermacro
    zabbix_valuemap
    zcbuildout
    zenoss
    zfs
    zk_concurrency
    zone
    zookeeper
    zpool
